@@ -107,3 +107,10 @@ def test_spacefree_link():
     tiddler.text = "This is [[Free Link]]@cdent: lorem ipsum"
     output = render(tiddler, environ)
     assert '<a href="http://cdent.tiddlyspace.org:8080/Free%20Link">Free Link</a>' in output
+
+@pytest.mark.skipif('tiddlyspace == False')
+def test_wiki_in_target():
+    tiddler = Tiddler('test')
+    tiddler.text = "[[posting|TiddlySpace Server Rebuild]]@blog"
+    output = render(tiddler, environ)
+    assert 'TiddlySpace' in output
